rlarg.fit(xdat, r = dim(xdat)[2], ydat = NULL, mul = NULL, sigl = NULL,
shl = NULL, mulink = identity, siglink = identity, shlink = identity,
muinit = NULL, siginit = NULL, shinit = NULL, show = TRUE,
method = "Nelder-Mead", maxit = 10000, ...)r order statistics are used for
the fitted model.NULL (the default) for stationary
fitting). The number of rows should be the same as the number
of rows of xdat.ydat that contain covariates for generalized linear
modelling of the location, scale and shape parameters repectively
(or NULL (the default) if the corresponding paraTRUE (the default), print details of
the fit.optim for
details).control argument of
optim.show is
TRUE, then assuming that successful convergence is
indicated, the components nllh, mle and se
are always printed.mul, sigl
and shl.optim. A zero indicates successful convergence.ydat should be
approximately centered and scaled).Let m=mean(xdat) and s=sqrt(6*var(xdat))/pi. Then, initial values assigend when 'muinit' is NULL are m - 0.57722 * s (stationary case). When 'siginit' is NULL, the initial value is taken to be s, and when 'shinit' is NULL, the initial value is taken to be 0.1. When covariates are introduced (non-stationary case), these same initial values are used by default for the constant term, and zeros for all other terms. For example, if a GEV( mu(t)=mu0+mu1*t, sigma, xi) is being fitted, then the initial value for mu0 is m - 0.57722 * s, and 0 for mu1.
rlarg.diag, optimdata(venice)
rlarg.fit(venice[,-1])Run the code above in your browser using DataLab